#!/bin/bash

port_1=5431
port_2=5432

# Clean up previous results

pg_ctl stop -D data_N2
pg_ctl stop -D data_N1

rm -r data_* *log

# Setup and start publisher
initdb -D data_N1 -U postgres
cat << EOF >> data_N1/postgresql.conf
wal_level = logical
port = $port_1
max_prepared_transactions = 10
EOF
pg_ctl -D data_N1 start -w -l N1.log

(
    echo -e "CREATE TABLE foo (a int);"
    echo -e "CREATE TABLE var (a int);"
    echo -e "CREATE PUBLICATION pub FOR ALL TABLES;"
) | psql -U postgres -p $port_1

# Setup and start subscriber with two_phase = false
initdb -D data_N2 -U postgres
cat << EOF >> data_N2/postgresql.conf
port = $port_2
max_prepared_transactions = 10
EOF
pg_ctl -D data_N2 start -w -l N2.log

(
    echo -e "CREATE TABLE foo (a int);"
    echo -e "CREATE TABLE var (a int);"
    echo -e "CREATE SUBSCRIPTION sub CONNECTION 'user=postgres port=$port_1' PUBLICATION pub WITH (two_phase=false, copy_data = false);"
) | psql -U postgres -p $port_2


# PREPARE transacitons
(
    echo -e "BEGIN; INSERT INTO foo VALUES (generate_series(1, 5)); PREPARE TRANSACTION 'txn1';"
    echo -e "BEGIN; INSERT INTO var VALUES (generate_series(1, 5)); PREPARE TRANSACTION 'txn2';"
) | psql -U postgres -p $port_1

sleep 1s

# ALTER SUBSCRIPTION to enable two-phase commit
(
    echo -e "ALTER SUBSCRIPTION sub DISABLE;"
    echo -e "ALTER SUBSCRIPTION sub SET (two_phase = true);"
    echo -e "ALTER SUBSCRIPTION sub ENABLE;"
) | psql -U postgres -p $port_2

sleep 1s

# Do COMMIT PREPARED. ERRORs will occur on subscriber...
(
    echo -e "COMMIT PREPARED 'txn1';"
    echo -e "COMMIT PREPARED 'txn2';"
) | psql -U postgres -p $port_1

